==> fd-faq-903.0-noarch-1.txz: usr/share/doc/fd-faq/desktop-icon-themes.md <==
%%textdomain fatdoghelp

 
![Fatdog64 logo](img/fatdog64-header.png)

#  
# Changing desktop icon themes
#  

There are a few ways to change the icon themes, depending on what "icon theme" we're talking about.

1. **The desktop icons** (also applies for some application icons you see on the menus)

There a symlink called **/usr/share/pixmaps/midi-icons** and **/usr/share/pixmaps/mini-icons**.  
-   **/usr/share/pixmaps/midi-icons** points to **/usr/share/pixmaps/themes/puppy48**
-   **/usr/share/pixmaps/mini-icons** points to **/usr/share/pixmaps/themes/puppy16**

You can install other icons in **/usr/share/pixmaps/themes** and re-symlink **/usr/share/pixmaps/midi-icons** (or mini-icons) as needed. Example - in the package repository, we have a package called **puppy-icon-theme** that installs to **/usr/share/pixmap/themes/Puppy-Standard**. You can re-symlink **/usr/share/pixmaps/midi-icons** to this directory. Note that puppy-icon-theme package does not have the mini-icons collection, so you will have find that elsewhere.





2\. **The icons you see inside ROX Filer**, they are stored in either **$HOME/.icons** or **/usr/share/icons**.

You can change it by right-click in ROX Filer, then choose **Options -> Types** and then you can change the icon theme.

We have 3 icons themes that installs in /usr/share/icons: **puppy-icon-theme**, **adwaita**, and **gnome-colors**. All of the can be used.

3\. Beyond this, we have **non-configurable icons**, that install themselves in **/usr/share/pixmaps** or **/usr/share/icons**.



They're mostly used for application icons (in menus). There is no way to replace them as a group; you will have to replace them individually. These are usually used by applications that pre-date the XDG standards (or could not care less about it).

4. And lastly, we have toolkit icon themes - like GTK icon themes, Qt icon themes, etc. These can be configured using the standard configuration mechanism for these toolkit. There are many pre-defined icon theme that you can use. Most of them are just tarballs that you can extract, and then you can edit the appropriate toolkit configuration files (e.g. .gtkrc-2.0 for GTK2, etc).

5\. Finally, we have **non-configurable icons in private application directories**, e.g. the "fatdog" start menu icons for lxqt-panel, the icons you see on the window manager decorations (to close/maximise/minimise windows, etc) from openbox, etc. These applications have their own "theme-ing" method and you just have to use your favourite search engine if you want to learn how change them. Some of the more popular window managers and panels (e.g. openbox) also have many themes you can use. For others, you have to figure out and assemble the themes yourself.


----

[Fatdog64](home.md)
| [FAQ index](faq.md)
| [FAQ files](faq_file_list.md)
| [Fatdog64 online](https://distro.ibiblio.org/fatdog/web)
| [FAQ online](https://distro.ibiblio.org/fatdog/web/faqs/faq.html)

----

_This page was automatically converted from [desktop-icon-themes.html](https://distro.ibiblio.org/fatdog/web/faqs/desktop-icon-themes.html) on 2024-08-05._

==> fd-faq-904.0-noarch-1.txz: usr/share/doc/fd-faq/desktop-icon-themes.md <==
 
![Fatdog64 logo](img/fatdog64-header.png)


# Changing desktop icon themes

There are a few ways to change the icon themes, depending on what "icon theme" we're talking about.  
1. **The desktop icons** (also applies for some application icons you see on the menus)  
There a symlink called **/usr/share/pixmaps/midi-icons** and **/usr/share/pixmaps/mini-icons**.

- **/usr/share/pixmaps/midi-icons** points to **/usr/share/pixmaps/themes/puppy48**
- **/usr/share/pixmaps/mini-icons** points to **/usr/share/pixmaps/themes/puppy16**

You can install other icons in **/usr/share/pixmaps/themes** and re-symlink **/usr/share/pixmaps/midi-icons** (or mini-icons) as needed. Example - in the package repository, we have a package called **puppy-icon-theme** that installs to **/usr/share/pixmap/themes/Puppy-Standard**. You can re-symlink **/usr/share/pixmaps/midi-icons** to this directory. Note that puppy-icon-theme package does not have the mini-icons collection, so you will have find that elsewhere.

2\. **The icons you see inside ROX Filer**, they are stored in either **$HOME/.icons** or **/usr/share/icons**.

You can change it by right-click in ROX Filer, then choose **Options -\> Types** and then you can change the icon theme.  
We have 3 icons themes that installs in /usr/share/icons: **puppy-icon-theme**, **adwaita**, and **gnome-colors**. All of the can be used.

3\. Beyond this, we have **non-configurable icons**, that install themselves in **/usr/share/pixmaps** or **/usr/share/icons**.

They're mostly used for application icons (in menus). There is no way to replace them as a group; you will have to replace them individually. These are usually used by applications that pre-date the XDG standards (or could not care less about it).

  
4. And lastly, we have toolkit icon themes - like GTK icon themes, Qt icon themes, etc. These can be configured using the standard configuration mechanism for these toolkit. There are many pre-defined icon theme that you can use. Most of them are just tarballs that you can extract, and then you can edit the appropriate toolkit configuration files (e.g. .gtkrc-2.0 for GTK2, etc).

5\. Finally, we have **non-configurable icons in private application directories**, e.g. the "fatdog" start menu icons for lxqt-panel, the icons you see on the window manager decorations (to close/maximise/minimise windows, etc) from openbox, etc. These applications have their own "theme-ing" method and you just have to use your favourite search engine if you want to learn how change them. Some of the more popular window managers and panels (e.g. openbox) also have many themes you can use. For others, you have to figure out and assemble the themes yourself.


----

[Fatdog64](home.md)
| [FAQ index](faq.md)
| [FAQ files](faq_file_list.md)
| [Fatdog64 online](https://distro.ibiblio.org/fatdog/web)
| [FAQ online](https://distro.ibiblio.org/fatdog/web/faqs/faq.html)

----

_This page was automatically converted from [desktop-icon-themes.html](https://distro.ibiblio.org/fatdog/web/faqs/desktop-icon-themes.html) on 2025-03-07._
